qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Qemu-devel] [PATCH v4 02/25] block: Use children list in bdrv_refresh_f


From: Max Reitz
Subject: [Qemu-devel] [PATCH v4 02/25] block: Use children list in bdrv_refresh_filename
Date: Wed, 11 Jan 2017 19:14:09 +0100

bdrv_refresh_filename() should invoke itself recursively on all
children, not just on file.

With that change, we can remove the manual invocations in blkverify and
quorum.

Signed-off-by: Max Reitz <address@hidden>
Reviewed-by: Eric Blake <address@hidden>
Reviewed-by: Alberto Garcia <address@hidden>
---
 block.c           | 9 +++++----
 block/blkverify.c | 3 ---
 block/quorum.c    | 1 -
 3 files changed, 5 insertions(+), 8 deletions(-)

diff --git a/block/blkverify.c b/block/blkverify.c
index 43a940c2f5..38a8c68029 100644
--- a/block/blkverify.c
+++ b/block/blkverify.c
@@ -284,9 +284,6 @@ static void blkverify_refresh_filename(BlockDriverState 
*bs, QDict *options)
 {
     BDRVBlkverifyState *s = bs->opaque;
 
-    /* bs->file->bs has already been refreshed */
-    bdrv_refresh_filename(s->test_file->bs);
-
     if (bs->file->bs->full_open_options
         && s->test_file->bs->full_open_options)
     {
diff --git a/block/quorum.c b/block/quorum.c
index 86e2072dce..112370eea2 100644
--- a/block/quorum.c
+++ b/block/quorum.c
@@ -1080,7 +1080,6 @@ static void quorum_refresh_filename(BlockDriverState *bs, 
QDict *options)
     int i;
 
     for (i = 0; i < s->num_children; i++) {
-        bdrv_refresh_filename(s->children[i]->bs);
         if (!s->children[i]->bs->full_open_options) {
             return;
         }
diff --git a/block.c b/block.c
index 39ddea3411..1615f5da1f 100644
--- a/block.c
+++ b/block.c
@@ -3948,16 +3948,17 @@ static bool append_open_options(QDict *d, 
BlockDriverState *bs)
 void bdrv_refresh_filename(BlockDriverState *bs)
 {
     BlockDriver *drv = bs->drv;
+    BdrvChild *child;
     QDict *opts;
 
     if (!drv) {
         return;
     }
 
-    /* This BDS's file name will most probably depend on its file's name, so
-     * refresh that first */
-    if (bs->file) {
-        bdrv_refresh_filename(bs->file->bs);
+    /* This BDS's file name may depend on any of its children's file names, so
+     * refresh those first */
+    QLIST_FOREACH(child, &bs->children, next) {
+        bdrv_refresh_filename(child->bs);
     }
 
     if (drv->bdrv_refresh_filename) {
-- 
2.11.0




reply via email to

[Prev in Thread] Current Thread [Next in Thread]